==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skgbasegui/skgtablewithgraphdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A table with graph for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtablewithgraphdesignerplugin.h"
#include "skgtablewithgraph.h"

#include "kicon.h"

#include <QtPlugin>

SKGTableWithGraphDesignerPlugin::SKGTableWithGraphDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        initialized = false;
}

void SKGTableWithGraphDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
        if (initialized) return;

        initialized = true;
}

bool SKGTableWithGraphDesignerPlugin::isInitialized() const
{
        return initialized;
}

QWidget *SKGTableWithGraphDesignerPlugin::createWidget(QWidget *parent)
{
        return new SKGTableWithGraph(parent);
}

QString SKGTableWithGraphDesignerPlugin::name() const
{
        return "SKGTableWithGraph";
}

QString SKGTableWithGraphDesignerPlugin::group() const
{
        return "SKG Widgets";
}

QIcon SKGTableWithGraphDesignerPlugin::icon() const
{
        return KIcon("skrooge.png");
}

QString SKGTableWithGraphDesignerPlugin::toolTip() const
{
        return "A Table with graph";
}

QString SKGTableWithGraphDesignerPlugin::whatsThis() const
{
        return "A Table with graph";
}

bool SKGTableWithGraphDesignerPlugin::isContainer() const
{
        return false;
}

QString SKGTableWithGraphDesignerPlugin::domXml() const
{
        return "<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
               " <property name=\"geometry\">\n"
               "  <rect>\n"
               "   <x>0</x>\n"
               "   <y>0</y>\n"
               "   <width>100</width>\n"
               "   <height>100</height>\n"
               "  </rect>\n"
               " </property>\n"
               "</widget>\n";
}

QString SKGTableWithGraphDesignerPlugin::includeFile() const
{
        return "skgtablewithgraph.h";
}

==> skrooge_0.7.2.2.orig.tar.gz: skrooge-0.7.2.2/skgbasegui/skgtablewithgraphdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A table with graph with more features (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtablewithgraphdesignerplugin.h"
#include "skgtablewithgraph.h"

#include "kicon.h"

#include <QtPlugin>

SKGTableWithGraphDesignerPlugin::SKGTableWithGraphDesignerPlugin(QObject *parent)
        : QObject(parent)
{
    initialized = false;
}

void SKGTableWithGraphDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
    if (initialized) return;

    initialized = true;
}

bool SKGTableWithGraphDesignerPlugin::isInitialized() const
{
    return initialized;
}

QWidget *SKGTableWithGraphDesignerPlugin::createWidget(QWidget *parent)
{
    return new SKGTableWithGraph(parent);
}

QString SKGTableWithGraphDesignerPlugin::name() const
{
    return "SKGTableWithGraph";
}

QString SKGTableWithGraphDesignerPlugin::group() const
{
    return "SKG Widgets";
}

QIcon SKGTableWithGraphDesignerPlugin::icon() const
{
    return KIcon("skg_open");
}

QString SKGTableWithGraphDesignerPlugin::toolTip() const
{
    return "A Table with graph";
}

QString SKGTableWithGraphDesignerPlugin::whatsThis() const
{
    return "A Table with graph";
}

bool SKGTableWithGraphDesignerPlugin::isContainer() const
{
    return false;
}

QString SKGTableWithGraphDesignerPlugin::domXml() const
{
    return "<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
           " <property name=\"geometry\">\n"
           "  <rect>\n"
           "   <x>0</x>\n"
           "   <y>0</y>\n"
           "   <width>100</width>\n"
           "   <height>100</height>\n"
           "  </rect>\n"
           " </property>\n"
           "</widget>\n";
}

QString SKGTableWithGraphDesignerPlugin::includeFile() const
{
    return "skgtablewithgraph.h";
}
